==> zio-aws-appstream_2.13-5.17.129.2-sources.jar: zio/aws/appstream/model/CreateStackResponse.scala <==
package zio.aws.appstream.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateStackResponse(
    stack: Option[zio.aws.appstream.model.Stack] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appstream.model.CreateStackResponse = {
    import CreateStackResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appstream.model.CreateStackResponse
      .builder()
      .optionallyWith(stack.map(value => value.buildAwsValue()))(_.stack)
      .build()
  }
  def asReadOnly: zio.aws.appstream.model.CreateStackResponse.ReadOnly =
    zio.aws.appstream.model.CreateStackResponse.wrap(buildAwsValue())
}
object CreateStackResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appstream.model.CreateStackResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appstream.model.CreateStackResponse =
      zio.aws.appstream.model
        .CreateStackResponse(stack.map(value => value.asEditable))
    def stack: Option[zio.aws.appstream.model.Stack.ReadOnly]
    def getStack: ZIO[Any, AwsError, zio.aws.appstream.model.Stack.ReadOnly] =
      AwsError.unwrapOptionField("stack", stack)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appstream.model.CreateStackResponse
  ) extends zio.aws.appstream.model.CreateStackResponse.ReadOnly {
    override val stack: Option[zio.aws.appstream.model.Stack.ReadOnly] = scala
      .Option(impl.stack())
      .map(value => zio.aws.appstream.model.Stack.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appstream.model.CreateStackResponse
  ): zio.aws.appstream.model.CreateStackResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appstream_2.13-5.17.167.1-sources.jar: zio/aws/appstream/model/CreateStackResponse.scala <==
package zio.aws.appstream.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateStackResponse(
    stack: Optional[zio.aws.appstream.model.Stack] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appstream.model.CreateStackResponse = {
    import CreateStackResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appstream.model.CreateStackResponse
      .builder()
      .optionallyWith(stack.map(value => value.buildAwsValue()))(_.stack)
      .build()
  }
  def asReadOnly: zio.aws.appstream.model.CreateStackResponse.ReadOnly =
    zio.aws.appstream.model.CreateStackResponse.wrap(buildAwsValue())
}
object CreateStackResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appstream.model.CreateStackResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appstream.model.CreateStackResponse =
      zio.aws.appstream.model
        .CreateStackResponse(stack.map(value => value.asEditable))
    def stack: Optional[zio.aws.appstream.model.Stack.ReadOnly]
    def getStack: ZIO[Any, AwsError, zio.aws.appstream.model.Stack.ReadOnly] =
      AwsError.unwrapOptionField("stack", stack)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appstream.model.CreateStackResponse
  ) extends zio.aws.appstream.model.CreateStackResponse.ReadOnly {
    override val stack: Optional[zio.aws.appstream.model.Stack.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stack())
        .map(value => zio.aws.appstream.model.Stack.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appstream.model.CreateStackResponse
  ): zio.aws.appstream.model.CreateStackResponse.ReadOnly = new Wrapper(impl)
}
